NLSL: dfunc.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

dfunc.f90
Go to the documentation of this file.
1 c NLSL Version 1.9.0 beta 2/12/15
2 c----------------------------------------------------------------------
3 c =========================
4 c module DFUNC
5 c =========================
6 c
7 c Contains storage for parameters related to the partial MOMD model.
8 c dlam The C20 coefficient for the director ordering potential
9 c xi Angle (in degrees) between the director ordering axis
10 c and B0
11 c cc The product cos(psi)*cos(xi) where psi is the angle betwwen
12 c the local director and B0
13 c ss The product sin(psi)*sin(xi)
14 c----------------------------------------------------------------------
15 c
16 module dfunc
17 implicit none
18 c
19 double precision, save :: dlam, xi, cc, ss
20 c
21 end module dfunc
dfunc::cc
double precision, save cc
Definition: dfunc.f90:19
dfunc::ss
double precision, save ss
Definition: dfunc.f90:19
dfunc::xi
double precision, save xi
Definition: dfunc.f90:19
dfunc::dlam
double precision, save dlam
Definition: dfunc.f90:19
dfunc
Definition: dfunc.f90:16